==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/enums/ScriptActivityParameterType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The type of the parameter.
 */
public enum class ScriptActivityParameterType(
    public val javaValue: com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType> {
    Boolean(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Boolean),
    DateTime(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.DateTime),
    DateTimeOffset(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.DateTimeOffset),
    Decimal(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Decimal),
    Double(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Double),
    Guid(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Guid),
    Int16(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Int16),
    Int32(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Int32),
    Int64(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Int64),
    Single(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Single),
    String(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.String),
    Timespan(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Timespan),
    ;

    override fun toJava(): com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType):
            ScriptActivityParameterType =
            ScriptActivityParameterType.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/enums/ScriptActivityParameterType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The type of the parameter.
 */
public enum class ScriptActivityParameterType(
    public val javaValue: com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType> {
    Boolean(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Boolean),
    DateTime(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.DateTime),
    DateTimeOffset(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.DateTimeOffset),
    Decimal(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Decimal),
    Double(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Double),
    Guid(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Guid),
    Int16(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Int16),
    Int32(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Int32),
    Int64(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Int64),
    Single(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Single),
    String(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.String),
    Timespan(com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType.Timespan),
    ;

    override fun toJava(): com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datafactory.enums.ScriptActivityParameterType): ScriptActivityParameterType =
            ScriptActivityParameterType.values().first { it.javaValue == javaType }
    }
}
